@@ -54,7 +54,7 @@ internal class AccountCreator(
         }
     }
 
-    private fun create(account: Account): String {
+    private suspend fun create(account: Account): String {
         val newAccount = preferences.newAccount(account.uuid)
 
         newAccount.email = account.emailAddress
