@@ -2,6 +2,7 @@ package app.k9mail.featureflag
 
 import net.thunderbird.core.featureflag.FeatureFlag
 import net.thunderbird.core.featureflag.FeatureFlagFactory
+import net.thunderbird.core.featureflag.FeatureFlagKey
 import net.thunderbird.core.featureflag.toFeatureFlagKey
 
 class K9FeatureFlagFactory : FeatureFlagFactory {
@@ -13,6 +14,8 @@ class K9FeatureFlagFactory : FeatureFlagFactory {
             FeatureFlag("email_notification_default".toFeatureFlagKey(), enabled = true),
             FeatureFlag("enable_dropdown_drawer".toFeatureFlagKey(), enabled = true),
             FeatureFlag("enable_dropdown_drawer_ui".toFeatureFlagKey(), enabled = true),
+            FeatureFlag(FeatureFlagKey.DisplayInAppNotifications, enabled = true),
+            FeatureFlag(FeatureFlagKey.UseNotificationSenderForSystemNotifications, enabled = true),
         )
     }
 }
