@@ -1,5 +1,3 @@
-import org.jetbrains.kotlin.gradle.internal.config.LanguageFeature
-
 plugins {
     id("com.android.library")
     id("org.jetbrains.kotlin.android")
@@ -27,7 +25,9 @@ android {
 
 kotlin {
     sourceSets.all {
-        languageSettings.enableLanguageFeature(LanguageFeature.WhenGuards.name)
+        compilerOptions {
+            freeCompilerArgs.add("-Xwhen-guards")
+        }
     }
 }
 
