@@ -10,7 +10,9 @@ dependencies {
     api(libs.junit)
     api(libs.robolectric)
 
-    implementation(projects.legacy.core)
+    implementation(projects.core.logging.api)
+    implementation(projects.core.preference.api)
+    implementation(projects.core.preference.impl)
 
     api(libs.koin.core)
     api(libs.mockito.core)
