@@ -2,13 +2,15 @@ package net.thunderbird.core.logging.composite
 
 import net.thunderbird.core.logging.LogEvent
 import net.thunderbird.core.logging.LogLevel
+import net.thunderbird.core.logging.LogLevelProvider
 import net.thunderbird.core.logging.LogSink
 
 internal class DefaultCompositeLogSink(
-    override val level: LogLevel,
+    private val logLevelProvider: LogLevelProvider,
     override val manager: CompositeLogSinkManager = DefaultLogSinkManager(),
     sinks: List<LogSink> = emptyList(),
 ) : CompositeLogSink {
+    override val level: LogLevel get() = logLevelProvider.current()
 
     init {
         manager.addAll(sinks)
