@@ -1,9 +1,9 @@
 package app.k9mail.feature.account.server.settings.domain.usecase
 
-import app.k9mail.core.common.domain.usecase.validation.ValidationError
-import app.k9mail.core.common.domain.usecase.validation.ValidationResult
-import app.k9mail.core.common.net.HostNameUtils
 import app.k9mail.feature.account.server.settings.domain.ServerSettingsDomainContract.UseCase
+import net.thunderbird.core.common.domain.usecase.validation.ValidationError
+import net.thunderbird.core.common.domain.usecase.validation.ValidationResult
+import net.thunderbird.core.common.net.HostNameUtils
 
 internal class ValidateServer : UseCase.ValidateServer {
 
