@@ -4,9 +4,8 @@ import android.content.Intent
 import android.net.Uri
 import android.os.Bundle
 import androidx.activity.compose.setContent
-import androidx.activity.enableEdgeToEdge
-import app.k9mail.core.ui.theme.api.FeatureThemeProvider
 import com.fsck.k9.ui.base.K9Activity
+import net.thunderbird.core.ui.theme.api.FeatureThemeProvider
 import org.koin.android.ext.android.inject
 
 class QrCodeScannerActivity : K9Activity() {
@@ -15,8 +14,6 @@ class QrCodeScannerActivity : K9Activity() {
     override fun onCreate(savedInstanceState: Bundle?) {
         super.onCreate(savedInstanceState)
 
-        enableEdgeToEdge()
-
         setContent {
             themeProvider.WithTheme(darkTheme = true) {
                 QrCodeScannerScreen(
