@@ -3,16 +3,17 @@ package net.thunderbird.feature.navigation.drawer.dropdown.ui.account
 import androidx.compose.runtime.Composable
 import androidx.compose.ui.tooling.preview.Preview
 import app.k9mail.core.ui.compose.designsystem.PreviewWithThemes
-import net.thunderbird.feature.navigation.drawer.dropdown.ui.FakeData.DISPLAY_ACCOUNT
+import net.thunderbird.feature.navigation.drawer.dropdown.ui.FakeData.MAIL_DISPLAY_ACCOUNT
 
 @Composable
 @Preview(showBackground = true)
 internal fun AccountListItemPreview() {
     PreviewWithThemes {
         AccountListItem(
-            account = DISPLAY_ACCOUNT,
+            account = MAIL_DISPLAY_ACCOUNT,
             onClick = { },
             selected = false,
+            showStarredCount = false,
         )
     }
 }
@@ -22,9 +23,10 @@ internal fun AccountListItemPreview() {
 internal fun AccountListItemSelectedPreview() {
     PreviewWithThemes {
         AccountListItem(
-            account = DISPLAY_ACCOUNT,
+            account = MAIL_DISPLAY_ACCOUNT,
             onClick = { },
             selected = true,
+            showStarredCount = false,
         )
     }
 }
