@@ -2,7 +2,10 @@ package net.thunderbird.feature.navigation.drawer.dropdown.domain.usecase
 
 import kotlinx.collections.immutable.persistentListOf
 import kotlinx.collections.immutable.toImmutableList
+import net.thunderbird.core.logging.Logger
+import net.thunderbird.feature.mail.folder.api.FOLDER_DEFAULT_PATH_DELIMITER
 import net.thunderbird.feature.mail.folder.api.Folder
+import net.thunderbird.feature.mail.folder.api.FolderPathDelimiter
 import net.thunderbird.feature.mail.folder.api.FolderType
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.DomainContract.UseCase
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayFolder
@@ -10,7 +13,9 @@ import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayT
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.MailDisplayFolder
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.UnifiedDisplayFolder
 
-internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
+internal class GetDisplayTreeFolder(
+    private val logger: Logger,
+) : UseCase.GetDisplayTreeFolder {
     private var placeholderCounter = 0L
 
     override fun invoke(folders: List<DisplayFolder>, maxDepth: Int): DisplayTreeFolder {
@@ -24,12 +29,13 @@ internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
             )
         }
 
+        val pathDelimiter = folders.firstOrNull()?.pathDelimiter ?: FOLDER_DEFAULT_PATH_DELIMITER
         val accountFolders = folders.filterIsInstance<MailDisplayFolder>().map {
-            val path = flattenPath(it.folder.name, maxDepth)
-            println("Flattened path for ${it.folder.name} → $path")
+            val path = flattenPath(it.folder.name, pathDelimiter, maxDepth)
+            logger.debug { "Flattened path for ${it.folder.name} → $path" }
             path to it
         }
-        val accountFolderTreeList = buildAccountFolderTree(accountFolders)
+        val accountFolderTreeList = buildAccountFolderTree(accountFolders, pathDelimiter)
 
         return DisplayTreeFolder(
             displayFolder = null,
@@ -40,18 +46,19 @@ internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
         )
     }
 
-    private fun flattenPath(folderName: String, maxDepth: Int): List<String> {
-        val parts = folderName.split("/").map { it.takeIf { it.isNotBlank() } ?: "(Unnamed)" }
+    private fun flattenPath(folderName: String, folderPathDelimiter: FolderPathDelimiter, maxDepth: Int): List<String> {
+        val parts = folderName.split(folderPathDelimiter).map { it.takeIf { it.isNotBlank() } ?: "(Unnamed)" }
 
         return if (parts.size <= maxDepth) {
             parts
         } else {
-            parts.take(maxDepth) + listOf(parts.drop(maxDepth).joinToString("/"))
+            parts.take(maxDepth) + listOf(parts.drop(maxDepth).joinToString(folderPathDelimiter))
         }
     }
 
     private fun buildAccountFolderTree(
         paths: List<Pair<List<String>, MailDisplayFolder>>,
+        pathDelimiter: FolderPathDelimiter,
         parentPath: String = "",
     ): List<DisplayTreeFolder> {
         return paths.groupBy { it.first.getOrNull(0) ?: "(Unnamed)" }
@@ -68,11 +75,15 @@ internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
                     if (segments.size == 1) folder else null
                 }
 
-                val fullPath = if (parentPath.isBlank()) segment else "$parentPath/$segment"
+                val fullPath = if (parentPath.isBlank()) segment else "${parentPath}${pathDelimiter}$segment"
 
-                val currentFolder = currentFolders.firstOrNull() ?: createPlaceholderFolder(fullPath)
+                val currentFolder = currentFolders.firstOrNull() ?: createPlaceholderFolder(fullPath, pathDelimiter)
 
-                val children = buildAccountFolderTree(childPaths, fullPath)
+                val children = buildAccountFolderTree(
+                    paths = childPaths,
+                    pathDelimiter = pathDelimiter,
+                    parentPath = fullPath,
+                )
 
                 val totalUnread = children.sumOf { it.totalUnreadCount } + currentFolder.unreadMessageCount
                 val totalStarred = children.sumOf { it.totalStarredCount } + currentFolder.starredMessageCount
@@ -87,10 +98,10 @@ internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
             }
     }
 
-    private fun createPlaceholderFolder(name: String): MailDisplayFolder {
+    private fun createPlaceholderFolder(name: String, pathDelimiter: FolderPathDelimiter): MailDisplayFolder {
         placeholderCounter += 1
         return MailDisplayFolder(
-            accountId = "placeholder",
+            accountId = null,
             folder = Folder(
                 id = placeholderCounter,
                 name = name,
@@ -100,6 +111,7 @@ internal class GetDisplayTreeFolder : UseCase.GetDisplayTreeFolder {
             isInTopGroup = true,
             unreadMessageCount = 0,
             starredMessageCount = 0,
+            pathDelimiter = pathDelimiter,
         )
     }
 }
