@@ -3,13 +3,13 @@ plugins {
 }
 
 dependencies {
-    implementation(projects.core.account)
+    implementation(projects.feature.mail.account.api)
+
     implementation(projects.legacy.ui.legacy)
     implementation(projects.legacy.core)
-    implementation(projects.legacy.account)
+    implementation(projects.core.android.account)
 
     implementation(libs.preferencex)
-    implementation(libs.timber)
 
     testImplementation(libs.robolectric)
 }
