@@ -1,10 +1,10 @@
 package com.fsck.k9.backends
 
-import app.k9mail.legacy.account.LegacyAccount
 import com.fsck.k9.mail.ServerSettings
 import com.fsck.k9.mail.store.imap.ImapStoreSettings
 import com.fsck.k9.mail.store.imap.ImapStoreSettings.autoDetectNamespace
 import com.fsck.k9.mail.store.imap.ImapStoreSettings.pathPrefix
+import net.thunderbird.core.android.account.LegacyAccount
 
 fun LegacyAccount.toImapServerSettings(): ServerSettings {
     val serverSettings = incomingServerSettings
