@@ -13,6 +13,7 @@ import com.fsck.k9.notification.NotificationController
 import com.fsck.k9.notification.NotificationStrategy
 import net.thunderbird.core.featureflag.FeatureFlagProvider
 import net.thunderbird.core.logging.Logger
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 import org.koin.core.qualifier.named
 import org.koin.dsl.module
 
@@ -32,6 +33,7 @@ val controllerModule = module {
             get(named("controllerExtensions")),
             get<FeatureFlagProvider>(),
             get<Logger>(named("syncDebug")),
+            get<OutboxFolderManager>(),
         )
     }
 
@@ -42,6 +44,7 @@ val controllerModule = module {
             accountManager = get(),
             messageStoreManager = get(),
             messagingControllerRegistry = get(),
+            outboxFolderManager = get(),
         )
     }
 
