@@ -1,9 +1,9 @@
 package com.fsck.k9.helper
 
-import app.k9mail.legacy.account.Identity
-import app.k9mail.legacy.account.LegacyAccount
 import com.fsck.k9.mail.Message
 import com.fsck.k9.mail.Message.RecipientType
+import net.thunderbird.core.android.account.Identity
+import net.thunderbird.core.android.account.LegacyAccount
 
 object IdentityHelper {
     private val RECIPIENT_TYPES = listOf(
