@@ -1,6 +1,8 @@
 package com.fsck.k9.job
 
+import androidx.work.WorkInfo
 import androidx.work.WorkManager
+import kotlinx.coroutines.flow.Flow
 import net.thunderbird.core.android.account.AccountManager
 import net.thunderbird.core.android.account.LegacyAccount
 import net.thunderbird.core.logging.legacy.Log
@@ -9,7 +11,16 @@ class K9JobManager(
     private val workManager: WorkManager,
     private val accountManager: AccountManager,
     private val mailSyncWorkerManager: MailSyncWorkerManager,
+    private val syncDebugFileLogManager: FileLogLimitWorkManager,
 ) {
+    fun scheduleDebugLogLimit(contentUriString: String): Flow<WorkInfo?> {
+        return syncDebugFileLogManager.scheduleFileLogTimeLimit(contentUriString)
+    }
+
+    fun cancelDebugLogLimit() {
+        syncDebugFileLogManager.cancelFileLogTimeLimit()
+    }
+
     fun scheduleAllMailJobs() {
         Log.v("scheduling all jobs")
         scheduleMailSync()
