@@ -7,17 +7,22 @@ import androidx.work.NetworkType
 import androidx.work.PeriodicWorkRequestBuilder
 import androidx.work.WorkManager
 import androidx.work.workDataOf
-import com.fsck.k9.K9
 import java.util.concurrent.TimeUnit
-import kotlinx.datetime.Clock
+import kotlin.time.Clock
+import kotlin.time.ExperimentalTime
 import net.thunderbird.core.android.account.LegacyAccount
 import net.thunderbird.core.logging.Logger
 import net.thunderbird.core.logging.legacy.Log
+import net.thunderbird.core.preference.BackgroundOps
+import net.thunderbird.core.preference.GeneralSettingsManager
 
-class MailSyncWorkerManager(
+class MailSyncWorkerManager
+@OptIn(ExperimentalTime::class)
+constructor(
     private val workManager: WorkManager,
     val clock: Clock,
     val syncDebugLogger: Logger,
+    val generalSettingsManager: GeneralSettingsManager,
 ) {
 
     fun cancelMailSync(account: LegacyAccount) {
@@ -67,7 +72,8 @@ class MailSyncWorkerManager(
         }
     }
 
-    private fun isNeverSyncInBackground() = K9.backgroundOps == K9.BACKGROUND_OPS.NEVER
+    private fun isNeverSyncInBackground() =
+        generalSettingsManager.getConfig().network.backgroundOps == BackgroundOps.NEVER
 
     private fun getSyncIntervalIfEnabled(account: LegacyAccount): Long? {
         val intervalMinutes = account.automaticCheckIntervalMinutes
@@ -79,6 +85,7 @@ class MailSyncWorkerManager(
     }
 
     private fun calculateInitialDelay(lastSyncTime: Long, syncIntervalMinutes: Long): Long {
+        @OptIn(ExperimentalTime::class)
         val now = clock.now().toEpochMilliseconds()
         val nextSyncTime = lastSyncTime + (syncIntervalMinutes * 60L * 1000L)
 
