@@ -3,10 +3,14 @@ package com.fsck.k9.mailstore
 import app.k9mail.legacy.mailstore.FolderRepository
 import app.k9mail.legacy.mailstore.MessageListRepository
 import app.k9mail.legacy.mailstore.MessageStoreManager
+import com.fsck.k9.mailstore.folder.DefaultOutboxFolderManager
 import com.fsck.k9.message.extractors.AttachmentCounter
 import com.fsck.k9.message.extractors.MessageFulltextCreator
 import com.fsck.k9.message.extractors.MessagePreviewCreator
+import kotlin.time.ExperimentalTime
 import net.thunderbird.backend.api.BackendStorageFactory
+import net.thunderbird.core.common.cache.TimeLimitedCache
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 import net.thunderbird.feature.mail.folder.api.SpecialFolderUpdater
 import org.koin.dsl.module
 
@@ -14,6 +18,7 @@ val mailStoreModule = module {
     single {
         FolderRepository(
             messageStoreManager = get(),
+            outboxFolderManager = get(),
         )
     }
     single { MessageViewInfoExtractorFactory(get(), get(), get()) }
@@ -38,7 +43,7 @@ val mailStoreModule = module {
     single<BackendStorageFactory<*>> {
         get<K9BackendStorageFactory>()
     }
-    factory { SpecialLocalFoldersCreator(preferences = get(), localStoreProvider = get()) }
+    factory { SpecialLocalFoldersCreator(preferences = get(), localStoreProvider = get(), outboxFolderManager = get()) }
     single { MessageStoreManager(accountManager = get(), messageStoreFactory = get()) }
     single { MessageRepository(messageStoreManager = get()) }
     factory { MessagePreviewCreator.newInstance() }
@@ -53,4 +58,12 @@ val mailStoreModule = module {
         )
     }
     single<MessageListRepository> { DefaultMessageListRepository(messageStoreManager = get()) }
+    single<OutboxFolderManager> {
+        DefaultOutboxFolderManager(
+            logger = get(),
+            accountManager = get(),
+            localStoreProvider = get(),
+            outboxFolderIdCache = @OptIn(ExperimentalTime::class)TimeLimitedCache(),
+        )
+    }
 }
