@@ -5,11 +5,13 @@ import androidx.core.app.NotificationCompat
 import androidx.core.app.NotificationManagerCompat
 import com.fsck.k9.mailstore.LocalFolder
 import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 
 internal class SyncNotificationController(
     private val notificationHelper: NotificationHelper,
     private val actionBuilder: NotificationActionCreator,
     private val resourceProvider: NotificationResourceProvider,
+    private val outboxFolderManager: OutboxFolderManager,
 ) {
     fun showSendingNotification(account: LegacyAccount) {
         val accountName = account.displayName
@@ -17,7 +19,10 @@ internal class SyncNotificationController(
         val tickerText = resourceProvider.sendingMailBody(accountName)
 
         val notificationId = NotificationIds.getFetchingMailNotificationId(account)
-        val outboxFolderId = account.outboxFolderId ?: error("Outbox folder not configured")
+        val outboxFolderId = outboxFolderManager
+            .getOutboxFolderIdSync(account.id)
+            .takeIf { it != -1L }
+            ?: error("Outbox folder not configured")
         val showMessageListPendingIntent = actionBuilder.createViewFolderPendingIntent(account, outboxFolderId)
 
         val notificationBuilder = notificationHelper
