@@ -12,12 +12,9 @@ import android.content.Context;
 import app.k9mail.feature.telemetry.api.TelemetryManager;
 import app.k9mail.legacy.di.DI;
 import com.fsck.k9.FontSizes;
-import com.fsck.k9.K9;
-import com.fsck.k9.K9.BACKGROUND_OPS;
 import com.fsck.k9.K9.NotificationQuickDelete;
 import com.fsck.k9.K9.PostMarkAsUnreadNavigation;
 import com.fsck.k9.K9.PostRemoveNavigation;
-import com.fsck.k9.K9.SplitViewMode;
 import com.fsck.k9.UiDensity;
 import com.fsck.k9.core.R;
 import com.fsck.k9.preferences.Settings.BooleanSetting;
@@ -40,10 +37,34 @@ import net.thunderbird.core.android.account.AccountDefaultsProvider;
 import net.thunderbird.core.android.account.SortType;
 import net.thunderbird.core.common.action.SwipeAction;
 import net.thunderbird.core.preference.AppTheme;
-import net.thunderbird.core.preference.storage.Storage;
+import net.thunderbird.core.preference.BackgroundOps;
+import net.thunderbird.core.preference.GeneralSettingsManager;
+import net.thunderbird.core.preference.SplitViewMode;
 import net.thunderbird.core.preference.SubTheme;
+import net.thunderbird.core.preference.display.coreSettings.DisplayCoreSettingsKt;
+import net.thunderbird.core.preference.network.NetworkSettingsKt;
+import net.thunderbird.core.preference.storage.Storage;
 
 import static com.fsck.k9.K9.LockScreenNotificationVisibility;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_AUTO_FIT_WIDTH;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_CHANGE_CONTACT_NAME_COLOR;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_ANIMATION;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CONTACT_NAME;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CONTACT_PICTURE;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CORRESPONDENT_NAMES;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_USE_MESSAGE_VIEW_FIXED_WIDTH_FONT;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_SHOULD_SHOW_SETUP_ARCHIVE_FOLDER_DIALOG;
+import static net.thunderbird.core.preference.display.DisplaySettingsKt.DISPLAY_SETTINGS_DEFAULT_SHOW_RECENT_CHANGES;
+import static net.thunderbird.core.preference.display.inboxSettings.DisplayInboxSettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_MESSAGE_LIST_SENDER_ABOVE_SUBJECT;
+import static net.thunderbird.core.preference.display.inboxSettings.DisplayInboxSettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_COMPOSE_BUTTON_ON_MESSAGE_LIST;
+import static net.thunderbird.core.preference.display.inboxSettings.DisplayInboxSettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_MESSAGE_LIST_STAR;
+import static net.thunderbird.core.preference.display.inboxSettings.DisplayInboxSettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_STAR_COUNT;
+import static net.thunderbird.core.preference.display.inboxSettings.DisplayInboxSettingsKt.DISPLAY_SETTINGS_DEFAULT_IS_SHOW_UNIFIED_INBOX;
+import static net.thunderbird.core.preference.notification.NotificationPreferenceKt.NOTIFICATION_PREFERENCE_DEFAULT_IS_QUIET_TIME_ENABLED;
+import static net.thunderbird.core.preference.notification.NotificationPreferenceKt.NOTIFICATION_PREFERENCE_DEFAULT_QUIET_TIME_END;
+import static net.thunderbird.core.preference.notification.NotificationPreferenceKt.NOTIFICATION_PREFERENCE_DEFAULT_QUIET_TIME_STARTS;
+import static net.thunderbird.core.preference.privacy.PrivacySettingsKt.PRIVACY_SETTINGS_DEFAULT_HIDE_TIME_ZONE;
+import static net.thunderbird.core.preference.privacy.PrivacySettingsKt.PRIVACY_SETTINGS_DEFAULT_HIDE_USER_AGENT;
 
 
 class GeneralSettingsDescriptions {
@@ -51,6 +72,7 @@ class GeneralSettingsDescriptions {
     private static final Map<Integer, SettingsUpgrader> UPGRADERS;
 
     private static final TelemetryManager telemetryManager = DI.get(TelemetryManager.class);
+    private static final GeneralSettingsManager generalSettingManager = DI.get(GeneralSettingsManager.class);
 
     static {
         Map<String, TreeMap<Integer, SettingsDescription<?>>> s = new LinkedHashMap<>();
@@ -61,239 +83,239 @@ class GeneralSettingsDescriptions {
          */
 
         s.put("animations", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_ANIMATION))
         ));
         s.put("backgroundOperations", Settings.versions(
-                new V(1, new EnumSetting<>(K9.BACKGROUND_OPS.class, K9.BACKGROUND_OPS.WHEN_CHECKED_AUTO_SYNC)),
-                new V(83, new EnumSetting<>(K9.BACKGROUND_OPS.class, BACKGROUND_OPS.ALWAYS))
+            new V(1, new EnumSetting<>(BackgroundOps.class, BackgroundOps.WHEN_CHECKED_AUTO_SYNC)),
+            new V(83, new EnumSetting<>(BackgroundOps.class, NetworkSettingsKt.getNETWORK_SETTINGS_DEFAULT_BACKGROUND_OPS()))
         ));
         s.put("changeRegisteredNameColor", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_CHANGE_CONTACT_NAME_COLOR))
         ));
         s.put("confirmDelete", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(false))
         ));
         s.put("confirmDeleteStarred", Settings.versions(
-                new V(2, new BooleanSetting(false))
+            new V(2, new BooleanSetting(false))
         ));
         s.put("confirmSpam", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(false))
         ));
         s.put("confirmMarkAllRead", Settings.versions(
-                new V(44, new BooleanSetting(true))
+            new V(44, new BooleanSetting(true))
         ));
         s.put("enableDebugLogging", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(false))
         ));
         s.put("enableSyncDebugLogging", Settings.versions(
             new V(103, new BooleanSetting(false))
         ));
         s.put("enableSensitiveLogging", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(false))
         ));
         s.put("fontSizeMessageComposeInput", Settings.versions(
-                new V(5, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(5, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageListDate", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageListPreview", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageListSender", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageListSubject", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewAdditionalHeaders", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewCC", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewContent", Settings.versions(
-                new V(1, new WebFontSizeSetting(3)),
-                new V(31, null)
+            new V(1, new WebFontSizeSetting(3)),
+            new V(31, null)
         ));
         s.put("fontSizeMessageViewDate", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewSender", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewSubject", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewTime", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("fontSizeMessageViewTo", Settings.versions(
-                new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(1, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("hideSpecialAccounts", Settings.versions(
-                new V(1, new BooleanSetting(false)),
-                new V(69, null)
+            new V(1, new BooleanSetting(false)),
+            new V(69, null)
         ));
         s.put("language", Settings.versions(
-                new V(1, new LanguageSetting())
+            new V(1, new LanguageSetting())
         ));
         s.put("messageListPreviewLines", Settings.versions(
-                new V(1, new IntegerRangeSetting(0, 6, 2))
+            new V(1, new IntegerRangeSetting(0, 6, 2))
         ));
         s.put("messageListStars", Settings.versions(
-                new V(1, new BooleanSetting(true))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_MESSAGE_LIST_STAR))
         ));
         s.put("messageViewFixedWidthFont", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_USE_MESSAGE_VIEW_FIXED_WIDTH_FONT))
         ));
         s.put("messageViewReturnToList", Settings.versions(
-                new V(1, new BooleanSetting(false)),
-                new V(89, null)
+            new V(1, new BooleanSetting(false)),
+            new V(89, null)
         ));
         s.put("messageViewShowNext", Settings.versions(
-                new V(1, new BooleanSetting(false)),
-                new V(89, null)
+            new V(1, new BooleanSetting(false)),
+            new V(89, null)
         ));
         s.put("quietTimeEnabled", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(NOTIFICATION_PREFERENCE_DEFAULT_IS_QUIET_TIME_ENABLED))
         ));
         s.put("quietTimeEnds", Settings.versions(
-                new V(1, new TimeSetting("7:00"))
+            new V(1, new TimeSetting(NOTIFICATION_PREFERENCE_DEFAULT_QUIET_TIME_END))
         ));
         s.put("quietTimeStarts", Settings.versions(
-                new V(1, new TimeSetting("21:00"))
+            new V(1, new TimeSetting(NOTIFICATION_PREFERENCE_DEFAULT_QUIET_TIME_STARTS))
         ));
         s.put("registeredNameColor", Settings.versions(
-                new V(1, new ColorSetting(0xFF00008F)),
-                new V(79, new ColorSetting(0xFF1093F5))
+            new V(1, new ColorSetting(0xFF00008F)),
+            new V(79, new ColorSetting(0xFF1093F5))
         ));
         s.put("showContactName", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CONTACT_NAME))
         ));
         s.put("showCorrespondentNames", Settings.versions(
-                new V(1, new BooleanSetting(true))
+            new V(1, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CORRESPONDENT_NAMES))
         ));
         s.put("showUnifiedInbox", Settings.versions(
-                new V(69, new BooleanSetting(true)),
-                new V(101, new BooleanSetting(false))
+            new V(69, new BooleanSetting(true)),
+            new V(101, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_UNIFIED_INBOX))
         ));
         s.put("isShowAccountSelector", Settings.versions(
             new V(102, new BooleanSetting(true))
         ));
         s.put("sortTypeEnum", Settings.versions(
-                new V(10, new EnumSetting<>(SortType.class, AccountDefaultsProvider.getDEFAULT_SORT_TYPE()))
+            new V(10, new EnumSetting<>(SortType.class, AccountDefaultsProvider.getDEFAULT_SORT_TYPE()))
         ));
         s.put("sortAscending", Settings.versions(
-                new V(10, new BooleanSetting(AccountDefaultsProvider.DEFAULT_SORT_ASCENDING))
+            new V(10, new BooleanSetting(AccountDefaultsProvider.DEFAULT_SORT_ASCENDING))
         ));
         s.put("theme", Settings.versions(
-                new V(1, new LegacyThemeSetting(AppTheme.LIGHT)),
-                new V(58, new ThemeSetting(AppTheme.FOLLOW_SYSTEM))
+            new V(1, new LegacyThemeSetting(AppTheme.LIGHT)),
+            new V(58, new ThemeSetting(DisplayCoreSettingsKt.getDISPLAY_SETTINGS_DEFAULT_APP_THEME()))
         ));
         s.put("messageViewTheme", Settings.versions(
-                new V(16, new LegacyThemeSetting(AppTheme.LIGHT)),
-                new V(24, new SubThemeSetting(SubTheme.USE_GLOBAL))
+            new V(16, new LegacyThemeSetting(AppTheme.LIGHT)),
+            new V(24, new SubThemeSetting(DisplayCoreSettingsKt.getDISPLAY_SETTINGS_DEFAULT_MESSAGE_VIEW_THEME()))
         ));
         s.put("useVolumeKeysForNavigation", Settings.versions(
-                new V(1, new BooleanSetting(false))
+            new V(1, new BooleanSetting(false))
         ));
         s.put("useBackgroundAsUnreadIndicator", Settings.versions(
-                new V(19, new BooleanSetting(true)),
-                new V(59, new BooleanSetting(false))
+            new V(19, new BooleanSetting(true)),
+            new V(59, new BooleanSetting(false))
         ));
         s.put("threadedView", Settings.versions(
-                new V(20, new BooleanSetting(true))
+            new V(20, new BooleanSetting(true))
         ));
         s.put("splitViewMode", Settings.versions(
-                new V(23, new EnumSetting<>(SplitViewMode.class, SplitViewMode.NEVER))
+            new V(23, new EnumSetting<>(SplitViewMode.class, SplitViewMode.NEVER))
         ));
         s.put("messageComposeTheme", Settings.versions(
-                new V(24, new SubThemeSetting(SubTheme.USE_GLOBAL))
+            new V(24, new SubThemeSetting(DisplayCoreSettingsKt.getDISPLAY_SETTINGS_DEFAULT_MESSAGE_COMPOSE_THEME()))
         ));
         s.put("fixedMessageViewTheme", Settings.versions(
-                new V(24, new BooleanSetting(true))
+            new V(24, new BooleanSetting(DisplayCoreSettingsKt.DISPLAY_SETTINGS_DEFAULT_FIXED_MESSAGE_VIEW_THEME))
         ));
         s.put("showContactPicture", Settings.versions(
-                new V(25, new BooleanSetting(true))
+            new V(25, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_CONTACT_PICTURE))
         ));
         s.put("autofitWidth", Settings.versions(
-                new V(28, new BooleanSetting(true))
+            new V(28, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_AUTO_FIT_WIDTH))
         ));
         s.put("colorizeMissingContactPictures", Settings.versions(
-                new V(29, new BooleanSetting(true))
+            new V(29, new BooleanSetting(true))
         ));
         s.put("messageViewDeleteActionVisible", Settings.versions(
-                new V(30, new BooleanSetting(true))
+            new V(30, new BooleanSetting(true))
         ));
         s.put("messageViewArchiveActionVisible", Settings.versions(
-                new V(30, new BooleanSetting(false))
+            new V(30, new BooleanSetting(false))
         ));
         s.put("messageViewMoveActionVisible", Settings.versions(
-                new V(30, new BooleanSetting(false))
+            new V(30, new BooleanSetting(false))
         ));
         s.put("messageViewCopyActionVisible", Settings.versions(
-                new V(30, new BooleanSetting(false))
+            new V(30, new BooleanSetting(false))
         ));
         s.put("messageViewSpamActionVisible", Settings.versions(
-                new V(30, new BooleanSetting(false))
+            new V(30, new BooleanSetting(false))
         ));
         s.put("fontSizeMessageViewContentPercent", Settings.versions(
-                new V(31, new IntegerRangeSetting(40, 250, 100))
+            new V(31, new IntegerRangeSetting(40, 250, 100))
         ));
         s.put("hideUserAgent", Settings.versions(
-                new V(32, new BooleanSetting(false))
+            new V(32, new BooleanSetting(PRIVACY_SETTINGS_DEFAULT_HIDE_USER_AGENT))
         ));
         s.put("hideTimeZone", Settings.versions(
-                new V(32, new BooleanSetting(false))
+            new V(32, new BooleanSetting(PRIVACY_SETTINGS_DEFAULT_HIDE_TIME_ZONE))
         ));
         s.put("lockScreenNotificationVisibility", Settings.versions(
-                new V(37, new EnumSetting<>(LockScreenNotificationVisibility.class,
-                        LockScreenNotificationVisibility.MESSAGE_COUNT))
+            new V(37, new EnumSetting<>(LockScreenNotificationVisibility.class,
+                LockScreenNotificationVisibility.MESSAGE_COUNT))
         ));
         s.put("confirmDeleteFromNotification", Settings.versions(
-                new V(38, new BooleanSetting(true))
+            new V(38, new BooleanSetting(true))
         ));
         s.put("messageListSenderAboveSubject", Settings.versions(
-                new V(38, new BooleanSetting(false))
+            new V(38, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_MESSAGE_LIST_SENDER_ABOVE_SUBJECT))
         ));
         s.put("notificationQuickDelete", Settings.versions(
-                new V(38, new EnumSetting<>(NotificationQuickDelete.class, NotificationQuickDelete.NEVER)),
-                new V(67, new EnumSetting<>(NotificationQuickDelete.class, NotificationQuickDelete.ALWAYS))
+            new V(38, new EnumSetting<>(NotificationQuickDelete.class, NotificationQuickDelete.NEVER)),
+            new V(67, new EnumSetting<>(NotificationQuickDelete.class, NotificationQuickDelete.ALWAYS))
         ));
         s.put("notificationDuringQuietTimeEnabled", Settings.versions(
-                new V(39, new BooleanSetting(true))
+            new V(39, new BooleanSetting(true))
         ));
         s.put("confirmDiscardMessage", Settings.versions(
-                new V(40, new BooleanSetting(true))
+            new V(40, new BooleanSetting(true))
         ));
         s.put("pgpInlineDialogCounter", Settings.versions(
-                new V(43, new IntegerRangeSetting(0, Integer.MAX_VALUE, 0))
+            new V(43, new IntegerRangeSetting(0, Integer.MAX_VALUE, 0))
         ));
         s.put("pgpSignOnlyDialogCounter", Settings.versions(
-                new V(45, new IntegerRangeSetting(0, Integer.MAX_VALUE, 0))
+            new V(45, new IntegerRangeSetting(0, Integer.MAX_VALUE, 0))
         ));
         s.put("fontSizeMessageViewBCC", Settings.versions(
-                new V(48, new FontSizeSetting(FontSizes.FONT_DEFAULT))
+            new V(48, new FontSizeSetting(FontSizes.FONT_DEFAULT))
         ));
         s.put("hideHostnameWhenConnecting", Settings.versions(
-                new V(49, new BooleanSetting(false)),
-                new V(56, null)
+            new V(49, new BooleanSetting(false)),
+            new V(56, null)
         ));
         s.put("showRecentChanges", Settings.versions(
-                new V(73, new BooleanSetting(true))
+            new V(73, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_SHOW_RECENT_CHANGES))
         ));
         s.put("showStarredCount", Settings.versions(
-                new V(75, new BooleanSetting(false))
+            new V(75, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_STAR_COUNT))
         ));
         s.put("swipeRightAction", Settings.versions(
-                new V(83, new EnumSetting<>(SwipeAction.class, SwipeAction.ToggleSelection))
+            new V(83, new EnumSetting<>(SwipeAction.class, SwipeAction.ToggleSelection))
         ));
         s.put("swipeLeftAction", Settings.versions(
-                new V(83, new EnumSetting<>(SwipeAction.class, SwipeAction.ToggleRead))
+            new V(83, new EnumSetting<>(SwipeAction.class, SwipeAction.ToggleRead))
         ));
         s.put("showComposeButtonOnMessageList", Settings.versions(
-            new V(85, new BooleanSetting(true))
+            new V(85, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_IS_SHOW_COMPOSE_BUTTON_ON_MESSAGE_LIST))
         ));
         s.put("messageListDensity", Settings.versions(
             new V(86, new EnumSetting<>(UiDensity.class, UiDensity.Default))
@@ -308,11 +330,8 @@ class GeneralSettingsDescriptions {
             new V(90,
                 new EnumSetting<>(PostMarkAsUnreadNavigation.class, PostMarkAsUnreadNavigation.ReturnToMessageList))
         ));
-        s.put(
-            RealGeneralSettingsManagerKt.KEY_SHOULD_SHOW_SETUP_ARCHIVE_FOLDER_DIALOG,
-            Settings.versions(
-                new V(105, new BooleanSetting(true))
-            )
+        s.put("shouldShowSetupArchiveFolderDialog", Settings.versions(
+            new V(105, new BooleanSetting(DISPLAY_SETTINGS_DEFAULT_SHOULD_SHOW_SETUP_ARCHIVE_FOLDER_DIALOG)))
         );
 
         // TODO: Add a way to properly support feature-specific settings.
@@ -340,7 +359,7 @@ class GeneralSettingsDescriptions {
     }
 
     public static Map<String, Object> upgrade(int version, Map<String, Object> validatedSettings) {
-        return SettingsUpgradeHelper.upgrade(version, UPGRADERS, SETTINGS, validatedSettings);
+        return SettingsUpgradeHelper.upgrade(version, UPGRADERS, SETTINGS, validatedSettings, generalSettingManager);
     }
 
     public static Map<String, String> convert(Map<String, Object> settings) {
@@ -423,8 +442,10 @@ class GeneralSettingsDescriptions {
         @Override
         public String toPrettyString(AppTheme value) {
             switch (value) {
-                case LIGHT: return THEME_LIGHT;
-                case DARK: return THEME_DARK;
+                case LIGHT:
+                    return THEME_LIGHT;
+                case DARK:
+                    return THEME_DARK;
             }
 
             throw new AssertionError("Unexpected case: " + value);
@@ -470,9 +491,12 @@ class GeneralSettingsDescriptions {
         @Override
         public String toPrettyString(AppTheme value) {
             switch (value) {
-                case LIGHT: return THEME_LIGHT;
-                case DARK: return THEME_DARK;
-                case FOLLOW_SYSTEM: return THEME_FOLLOW_SYSTEM;
+                case LIGHT:
+                    return THEME_LIGHT;
+                case DARK:
+                    return THEME_DARK;
+                case FOLLOW_SYSTEM:
+                    return THEME_FOLLOW_SYSTEM;
             }
 
             throw new AssertionError("Unexpected case: " + value);
@@ -518,9 +542,12 @@ class GeneralSettingsDescriptions {
         @Override
         public String toPrettyString(SubTheme value) {
             switch (value) {
-                case LIGHT: return THEME_LIGHT;
-                case DARK: return THEME_DARK;
-                case USE_GLOBAL: return THEME_USE_GLOBAL;
+                case LIGHT:
+                    return THEME_LIGHT;
+                case DARK:
+                    return THEME_DARK;
+                case USE_GLOBAL:
+                    return THEME_USE_GLOBAL;
             }
 
             throw new AssertionError("Unexpected case: " + value);
