@@ -1,10 +1,10 @@
 package com.fsck.k9.search
 
 import net.thunderbird.core.android.account.LegacyAccount
-import net.thunderbird.feature.search.LocalMessageSearch
-import net.thunderbird.feature.search.api.MessageSearchField
-import net.thunderbird.feature.search.api.SearchAttribute
-import net.thunderbird.feature.search.api.SearchCondition
+import net.thunderbird.feature.search.legacy.LocalMessageSearch
+import net.thunderbird.feature.search.legacy.api.MessageSearchField
+import net.thunderbird.feature.search.legacy.api.SearchAttribute
+import net.thunderbird.feature.search.legacy.api.SearchCondition
 
 /**
  * Modify the supplied [LocalMessageSearch] instance to limit the search to displayable folders.
@@ -29,11 +29,11 @@ fun LocalMessageSearch.limitToDisplayableFolders() {
  *
  * The Inbox will always be included even if one of the special folders is configured to point to the Inbox.
  */
-fun LocalMessageSearch.excludeSpecialFolders(account: LegacyAccount) {
+fun LocalMessageSearch.excludeSpecialFolders(account: LegacyAccount, outboxFolderId: Long) {
     this.excludeSpecialFolder(account.trashFolderId)
     this.excludeSpecialFolder(account.draftsFolderId)
     this.excludeSpecialFolder(account.spamFolderId)
-    this.excludeSpecialFolder(account.outboxFolderId)
+    this.excludeSpecialFolder(outboxFolderId)
     this.excludeSpecialFolder(account.sentFolderId)
 
     account.inboxFolderId?.let { inboxFolderId ->
