@@ -17,15 +17,21 @@ import net.thunderbird.core.featureflag.FeatureFlag
 import net.thunderbird.core.featureflag.FeatureFlagProvider
 import net.thunderbird.core.featureflag.InMemoryFeatureFlagProvider
 import net.thunderbird.core.logging.LogLevel
+import net.thunderbird.core.logging.LogLevelManager
+import net.thunderbird.core.logging.LogLevelProvider
 import net.thunderbird.core.logging.Logger
 import net.thunderbird.core.logging.composite.CompositeLogSink
 import net.thunderbird.core.logging.composite.CompositeLogSinkManager
 import net.thunderbird.core.logging.file.FileLogSink
 import net.thunderbird.core.logging.legacy.Log
+import net.thunderbird.core.logging.testing.TestLogLevelManager
 import net.thunderbird.core.logging.testing.TestLogger
 import net.thunderbird.core.preference.storage.StoragePersister
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 import net.thunderbird.legacy.core.FakeAccountDefaultsProvider
+import net.thunderbird.legacy.core.mailstore.folder.FakeOutboxFolderManager
 import org.koin.core.qualifier.named
+import org.koin.dsl.bind
 import org.koin.dsl.module
 import org.mockito.kotlin.mock
 
@@ -52,7 +58,7 @@ class TestApp : Application() {
         val fileSink: FileLogSink = mock<FileLogSink>()
 
         val compositeSink: CompositeLogSink = CompositeLogSink(
-            level = LogLevel.DEBUG,
+            logLevelProvider = { LogLevel.DEBUG },
             manager = sinkManager,
             sinks = listOf(fileSink),
         )
@@ -61,6 +67,7 @@ class TestApp : Application() {
 
 val testModule = module {
     single<Logger> { TestApp.logger }
+    single<LogLevelManager> { TestLogLevelManager() }.bind<LogLevelProvider>()
     single(named("syncDebug")) { TestApp.logger }
     single(named("syncDebug")) { TestApp.compositeSink }
     single(named("syncDebug")) { TestApp.fileSink }
@@ -83,4 +90,5 @@ val testModule = module {
             },
         )
     }
+    single<OutboxFolderManager> { FakeOutboxFolderManager() }
 }
