@@ -9,12 +9,15 @@ import assertk.assertions.isFalse
 import assertk.assertions.isInstanceOf
 import assertk.assertions.isTrue
 import com.fsck.k9.K9
-import kotlinx.datetime.Clock
+import java.util.Calendar
+import kotlin.time.Clock
+import kotlin.time.ExperimentalTime
+import kotlin.time.Instant
 import net.thunderbird.core.android.account.LegacyAccount
-import net.thunderbird.core.preference.AppTheme
-import net.thunderbird.core.preference.BackgroundSync
 import net.thunderbird.core.preference.GeneralSettings
-import net.thunderbird.core.preference.SubTheme
+import net.thunderbird.core.preference.display.DisplaySettings
+import net.thunderbird.core.preference.network.NetworkSettings
+import net.thunderbird.core.preference.notification.NotificationPreference
 import net.thunderbird.core.preference.privacy.PrivacySettings
 import net.thunderbird.core.testing.TestClock
 import org.junit.After
@@ -23,50 +26,28 @@ import org.junit.Test
 import org.koin.core.context.startKoin
 import org.koin.core.context.stopKoin
 import org.koin.dsl.module
-import org.mockito.Mockito.mock
 import org.mockito.kotlin.doReturn
 import org.mockito.kotlin.mock
 
 private val TIMESTAMP = 0L
 
+@OptIn(ExperimentalTime::class)
 class SummaryNotificationDataCreatorTest {
     private val account = createAccount()
+    private val testClock = TestClock()
     private var generalSettings = GeneralSettings(
-        backgroundSync = BackgroundSync.ALWAYS,
-        showRecentChanges = true,
-        appTheme = AppTheme.DARK,
-        messageComposeTheme = SubTheme.DARK,
-        isShowCorrespondentNames = true,
-        fixedMessageViewTheme = true,
-        messageViewTheme = SubTheme.DARK,
-        isShowStarredCount = false,
-        isShowUnifiedInbox = false,
-        isShowMessageListStars = false,
-        isShowAnimations = false,
-        shouldShowSetupArchiveFolderDialog = false,
-        isMessageListSenderAboveSubject = false,
-        isShowContactName = false,
-        isShowContactPicture = false,
-        isChangeContactNameColor = false,
-        isColorizeMissingContactPictures = false,
-        isUseBackgroundAsUnreadIndicator = false,
-        isShowComposeButtonOnMessageList = false,
-        isThreadedViewEnabled = false,
-        isUseMessageViewFixedWidthFont = false,
-        isAutoFitWidth = false,
-        isQuietTime = false,
-        quietTimeStarts = "0:00",
-        quietTimeEnds = "23:59",
-        isQuietTimeEnabled = false,
-        privacy = PrivacySettings(
-            isHideTimeZone = false,
-            isHideUserAgent = false,
+        display = DisplaySettings(),
+        network = NetworkSettings(),
+        notification = NotificationPreference(
+            quietTimeStarts = "23:00",
+            quietTimeEnds = "00:00",
         ),
+        privacy = PrivacySettings(),
     )
     private val notificationDataCreator = SummaryNotificationDataCreator(
         singleMessageNotificationDataCreator = SingleMessageNotificationDataCreator(),
         generalSettingsManager = mock {
-            on { getSettings() } doReturn generalSettings
+            on { getConfig() } doReturn generalSettings
         },
     )
 
@@ -75,7 +56,7 @@ class SummaryNotificationDataCreatorTest {
         startKoin {
             modules(
                 module {
-                    single<Clock> { TestClock() }
+                    single<Clock> { testClock }
                 },
             )
         }
@@ -101,13 +82,16 @@ class SummaryNotificationDataCreatorTest {
 
     @Test
     fun `single notification during quiet time`() {
+        setClockTo("23:01")
         setQuietTime(true)
         val notificationData = createNotificationData()
 
         val result = SummaryNotificationDataCreator(
             singleMessageNotificationDataCreator = SingleMessageNotificationDataCreator(),
             generalSettingsManager = mock {
-                on { getSettings() } doReturn generalSettings.copy(isQuietTime = true, isQuietTimeEnabled = true)
+                on { getConfig() } doReturn generalSettings.copy(
+                    notification = generalSettings.notification.copy(isQuietTimeEnabled = true),
+                )
             },
         ).createSummaryNotificationData(
             notificationData,
@@ -134,13 +118,16 @@ class SummaryNotificationDataCreatorTest {
 
     @Test
     fun `inbox-style notification during quiet time`() {
+        setClockTo("23:01")
         setQuietTime(true)
         val notificationData = createNotificationDataWithMultipleMessages()
 
         val result = SummaryNotificationDataCreator(
             singleMessageNotificationDataCreator = SingleMessageNotificationDataCreator(),
             generalSettingsManager = mock {
-                on { getSettings() } doReturn generalSettings.copy(isQuietTime = true, isQuietTimeEnabled = true)
+                on { getConfig() } doReturn generalSettings.copy(
+                    notification = generalSettings.notification.copy(isQuietTimeEnabled = true),
+                )
             },
         ).createSummaryNotificationData(
             notificationData,
@@ -288,7 +275,9 @@ class SummaryNotificationDataCreatorTest {
     }
 
     private fun setQuietTime(quietTime: Boolean) {
-        generalSettings = generalSettings.copy(isQuietTimeEnabled = quietTime)
+        generalSettings = generalSettings.copy(
+            notification = generalSettings.notification.copy(isQuietTimeEnabled = quietTime),
+        )
     }
 
     private fun setDeleteAction(mode: K9.NotificationQuickDelete) {
@@ -331,4 +320,14 @@ class SummaryNotificationDataCreatorTest {
         }
         return createNotificationData(contentList)
     }
+
+    private fun setClockTo(time: String) {
+        val (hourOfDay, minute) = time.split(':').map { it.toInt() }
+
+        val calendar = Calendar.getInstance()
+        calendar.set(Calendar.HOUR_OF_DAY, hourOfDay)
+        calendar.set(Calendar.MINUTE, minute)
+
+        testClock.changeTimeTo(Instant.fromEpochMilliseconds(calendar.timeInMillis))
+    }
 }
