@@ -2,7 +2,6 @@ package app.k9mail.legacy.mailstore
 
 import app.k9mail.legacy.mailstore.FolderTypeMapper.folderTypeOf
 import app.k9mail.legacy.mailstore.RemoteFolderTypeMapper.toFolderType
-import com.fsck.k9.mail.MessagingException
 import kotlinx.coroutines.CoroutineDispatcher
 import kotlinx.coroutines.Dispatchers
 import kotlinx.coroutines.channels.Channel
@@ -14,35 +13,41 @@ import kotlinx.coroutines.flow.callbackFlow
 import kotlinx.coroutines.flow.distinctUntilChanged
 import kotlinx.coroutines.flow.flowOn
 import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.common.exception.MessagingException
 import net.thunderbird.feature.mail.folder.api.Folder
 import net.thunderbird.feature.mail.folder.api.FolderDetails
+import net.thunderbird.feature.mail.folder.api.FolderType
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 import net.thunderbird.feature.mail.folder.api.RemoteFolder
 
 @Suppress("TooManyFunctions")
 class FolderRepository(
     private val messageStoreManager: MessageStoreManager,
+    private val outboxFolderManager: OutboxFolderManager,
     private val ioDispatcher: CoroutineDispatcher = Dispatchers.IO,
 ) {
-    fun getFolder(account: LegacyAccount, folderId: Long): Folder? {
+    suspend fun getFolder(account: LegacyAccount, folderId: Long): Folder? {
         val messageStore = messageStoreManager.getMessageStore(account)
+        val outboxFolderId = outboxFolderManager.getOutboxFolderId(account.id)
         return messageStore.getFolder(folderId) { folder ->
             Folder(
                 id = folder.id,
                 name = folder.name,
-                type = folderTypeOf(account, folder.id),
+                type = folder.getFolderType(account, outboxFolderId),
                 isLocalOnly = folder.isLocalOnly,
             )
         }
     }
 
-    fun getFolderDetails(account: LegacyAccount, folderId: Long): FolderDetails? {
+    suspend fun getFolderDetails(account: LegacyAccount, folderId: Long): FolderDetails? {
         val messageStore = messageStoreManager.getMessageStore(account)
+        val outboxFolderId = outboxFolderManager.getOutboxFolderId(account.id)
         return messageStore.getFolder(folderId) { folder ->
             FolderDetails(
                 folder = Folder(
                     id = folder.id,
                     name = folder.name,
-                    type = folderTypeOf(account, folder.id),
+                    type = folder.getFolderType(account, outboxFolderId),
                     isLocalOnly = folder.isLocalOnly,
                 ),
                 isInTopGroup = folder.isInTopGroup,
@@ -187,6 +192,13 @@ class FolderRepository(
             .distinctUntilChanged()
             .flowOn(ioDispatcher)
     }
+
+    private fun FolderDetailsAccessor.getFolderType(account: LegacyAccount, outboxFolderId: Long): FolderType =
+        if (id == outboxFolderId) {
+            FolderType.OUTBOX
+        } else {
+            folderTypeOf(account, id)
+        }
 }
 
 data class RemoteFolderDetails(
