@@ -1,6 +1,6 @@
 package app.k9mail.legacy.mailstore
 
-import app.k9mail.legacy.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccount
 
 interface MessageStoreFactory {
     fun create(account: LegacyAccount): ListenableMessageStore
