@@ -2,8 +2,8 @@ package app.k9mail.legacy.message.controller
 
 import kotlinx.coroutines.flow.Flow
 import net.thunderbird.core.android.account.LegacyAccount
-import net.thunderbird.feature.search.LocalMessageSearch
-import net.thunderbird.feature.search.SearchAccount
+import net.thunderbird.feature.search.legacy.LocalMessageSearch
+import net.thunderbird.feature.search.legacy.SearchAccount
 
 interface MessageCountsProvider {
     fun getMessageCounts(account: LegacyAccount): MessageCounts
