@@ -29,12 +29,6 @@ internal class MigrationTo76(private val db: SQLiteDatabase, private val migrati
     fun cleanUpSpecialLocalFolders() {
         val account = migrationsHelper.account
 
-        Log.v("Cleaning up Outbox folder")
-        val outboxFolderId =
-            account.outboxFolderId ?: createFolder("Outbox", "K9MAIL_INTERNAL_OUTBOX", OUTBOX_FOLDER_TYPE)
-        deleteOtherOutboxFolders(outboxFolderId)
-        account.outboxFolderId = outboxFolderId
-
         if (account.isPop3()) {
             Log.v("Cleaning up Drafts folder")
             val draftsFolderId = account.draftsFolderId ?: createFolder("Drafts", "Drafts", DRAFTS_FOLDER_TYPE)
@@ -76,13 +70,6 @@ internal class MigrationTo76(private val db: SQLiteDatabase, private val migrati
         return folderId
     }
 
-    private fun deleteOtherOutboxFolders(outboxFolderId: Long) {
-        val otherFolderIds = getOtherFolders(OUTBOX_FOLDER_TYPE, outboxFolderId)
-        for (folderId in otherFolderIds) {
-            deleteFolder(folderId)
-        }
-    }
-
     private fun getOtherFolders(folderType: String, excludeFolderId: Long): List<Long> {
         return db.query(
             "folders",
@@ -124,7 +111,6 @@ internal class MigrationTo76(private val db: SQLiteDatabase, private val migrati
     private fun LegacyAccount.isPop3() = incomingServerSettings.type == Protocols.POP3
 
     companion object {
-        private const val OUTBOX_FOLDER_TYPE = "outbox"
         private const val DRAFTS_FOLDER_TYPE = "drafts"
         private const val SENT_FOLDER_TYPE = "sent"
         private const val TRASH_FOLDER_TYPE = "trash"
