@@ -19,7 +19,7 @@ import kotlinx.coroutines.withContext
 import net.thunderbird.core.android.account.LegacyAccount
 import net.thunderbird.core.preference.GeneralSettingsManager
 import net.thunderbird.feature.mail.account.api.BaseAccount
-import net.thunderbird.feature.search.SearchAccount.Companion.createUnifiedInboxAccount
+import net.thunderbird.feature.search.legacy.SearchAccount
 import org.koin.android.ext.android.inject
 
 /**
@@ -76,8 +76,8 @@ abstract class AccountList : K9ListActivity(), OnItemClickListener {
     private fun populateListView(realAccounts: List<LegacyAccount>) {
         val accounts: MutableList<BaseAccount> = ArrayList()
 
-        if (generalSettingsManager.getSettings().isShowUnifiedInbox) {
-            val unifiedInboxAccount: BaseAccount = createUnifiedInboxAccount(
+        if (generalSettingsManager.getConfig().display.inboxSettings.isShowUnifiedInbox) {
+            val unifiedInboxAccount: BaseAccount = SearchAccount.createUnifiedInboxAccount(
                 unifiedInboxTitle = coreResourceProvider.searchUnifiedInboxTitle(),
                 unifiedInboxDetail = coreResourceProvider.searchUnifiedInboxDetail(),
             )
