@@ -9,6 +9,7 @@ import de.cketti.changelog.ReleaseItem
 import kotlinx.coroutines.flow.distinctUntilChanged
 import kotlinx.coroutines.flow.map
 import net.thunderbird.core.preference.GeneralSettingsManager
+import net.thunderbird.core.preference.update
 
 private typealias ChangeLogState = LoaderState<List<ReleaseItem>>
 
@@ -18,8 +19,8 @@ class ChangelogViewModel(
     private val mode: ChangeLogMode,
 ) : ViewModel() {
     val showRecentChangesState: LiveData<Boolean> =
-        generalSettingsManager.getSettingsFlow()
-            .map { it.showRecentChanges }
+        generalSettingsManager.getConfigFlow()
+            .map { it.display.showRecentChanges }
             .distinctUntilChanged()
             .asLiveData()
 
@@ -32,7 +33,9 @@ class ChangelogViewModel(
     }
 
     fun setShowRecentChanges(showRecentChanges: Boolean) {
-        generalSettingsManager.setShowRecentChanges(showRecentChanges)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(showRecentChanges = showRecentChanges))
+        }
     }
 
     override fun onCleared() {
