@@ -7,11 +7,13 @@ import com.fsck.k9.helper.MessageHelper
 import com.fsck.k9.ui.helper.DisplayAddressHelper
 import net.thunderbird.core.android.account.LegacyAccount
 import net.thunderbird.core.preference.GeneralSettingsManager
+import net.thunderbird.feature.mail.folder.api.OutboxFolderManager
 
 class MessageListItemMapper(
     private val messageHelper: MessageHelper,
     private val account: LegacyAccount,
     private val generalSettingsManager: GeneralSettingsManager,
+    private val outboxFolderManager: OutboxFolderManager,
 ) : MessageMapper<MessageListItem> {
 
     override fun map(message: MessageDetailsAccessor): MessageListItem {
@@ -21,13 +23,13 @@ class MessageListItemMapper(
         val isMessageEncrypted = previewResult.previewType == PreviewType.ENCRYPTED
         val previewText = if (previewResult.isPreviewTextAvailable) previewResult.previewText else ""
         val uniqueId = createUniqueId(account, message.id)
-        val showRecipients = DisplayAddressHelper.shouldShowRecipients(account, message.folderId)
+        val showRecipients = DisplayAddressHelper.shouldShowRecipients(outboxFolderManager, account, message.folderId)
         val displayAddress = if (showRecipients) toAddresses.firstOrNull() else fromAddresses.firstOrNull()
         val displayName = if (showRecipients) {
             messageHelper.getRecipientDisplayNames(
                 addresses = toAddresses.toTypedArray(),
-                isShowCorrespondentNames = generalSettingsManager.getSettings().isShowCorrespondentNames,
-                isChangeContactNameColor = generalSettingsManager.getSettings().isChangeContactNameColor,
+                isShowCorrespondentNames = generalSettingsManager.getConfig().display.isShowCorrespondentNames,
+                isChangeContactNameColor = generalSettingsManager.getConfig().display.isChangeContactNameColor,
             )
         } else {
             messageHelper.getSenderDisplayName(displayAddress)
