@@ -10,8 +10,11 @@ import com.fsck.k9.job.K9JobManager
 import com.fsck.k9.ui.base.AppLanguageManager
 import net.thunderbird.core.common.action.SwipeAction
 import net.thunderbird.core.preference.AppTheme
+import net.thunderbird.core.preference.BackgroundOps
 import net.thunderbird.core.preference.GeneralSettingsManager
+import net.thunderbird.core.preference.SplitViewMode
 import net.thunderbird.core.preference.SubTheme
+import net.thunderbird.core.preference.update
 
 class GeneralSettingsDataStore(
     private val jobManager: K9JobManager,
@@ -24,32 +27,52 @@ class GeneralSettingsDataStore(
 
     override fun getBoolean(key: String, defValue: Boolean): Boolean {
         return when (key) {
-            "fixed_message_view_theme" -> generalSettingsManager.getSettings().fixedMessageViewTheme
-            "animations" -> generalSettingsManager.getSettings().isShowAnimations
-            "show_unified_inbox" -> generalSettingsManager.getSettings().isShowUnifiedInbox
-            "show_starred_count" -> generalSettingsManager.getSettings().isShowStarredCount
-            "messagelist_stars" -> generalSettingsManager.getSettings().isShowMessageListStars
-            "messagelist_show_correspondent_names" -> generalSettingsManager.getSettings().isShowCorrespondentNames
-            "messagelist_sender_above_subject" -> generalSettingsManager.getSettings().isMessageListSenderAboveSubject
-            "messagelist_show_contact_name" -> generalSettingsManager.getSettings().isShowContactName
-            "messagelist_change_contact_name_color" -> generalSettingsManager.getSettings().isChangeContactNameColor
-            "messagelist_show_contact_picture" -> generalSettingsManager.getSettings().isShowContactPicture
-            "messagelist_colorize_missing_contact_pictures" -> generalSettingsManager.getSettings()
-                .isColorizeMissingContactPictures
+            "fixed_message_view_theme" -> generalSettingsManager.getConfig().display.coreSettings.fixedMessageViewTheme
+            "animations" -> generalSettingsManager.getConfig().display.isShowAnimations
+            "show_unified_inbox" -> generalSettingsManager.getConfig().display.inboxSettings.isShowUnifiedInbox
+            "show_starred_count" -> generalSettingsManager.getConfig().display.inboxSettings.isShowStarredCount
+            "messagelist_stars" -> generalSettingsManager.getConfig().display.inboxSettings.isShowMessageListStars
+            "messagelist_show_correspondent_names" -> generalSettingsManager.getConfig()
+                .display.isShowCorrespondentNames
 
-            "messagelist_background_as_unread_indicator" -> generalSettingsManager.getSettings()
-                .isUseBackgroundAsUnreadIndicator
+            "messagelist_sender_above_subject" -> generalSettingsManager.getConfig()
+                .display.inboxSettings.isMessageListSenderAboveSubject
+
+            "messagelist_show_contact_name" -> generalSettingsManager.getConfig()
+                .display.isShowContactName
+
+            "messagelist_change_contact_name_color" -> generalSettingsManager.getConfig()
+                .display.isChangeContactNameColor
+
+            "messagelist_show_contact_picture" -> generalSettingsManager.getConfig()
+                .display.isShowContactPicture
+
+            "messagelist_colorize_missing_contact_pictures" -> generalSettingsManager.getConfig()
+                .display.isColorizeMissingContactPictures
+
+            "messagelist_background_as_unread_indicator" -> generalSettingsManager.getConfig()
+                .display.isUseBackgroundAsUnreadIndicator
+
+            "show_compose_button" -> generalSettingsManager.getConfig()
+                .display.inboxSettings.isShowComposeButtonOnMessageList
+
+            "threaded_view" -> generalSettingsManager.getConfig()
+                .display.inboxSettings.isThreadedViewEnabled
+
+            "messageview_fixedwidth_font" -> generalSettingsManager.getConfig()
+                .display.isUseMessageViewFixedWidthFont
+
+            "messageview_autofit_width" -> generalSettingsManager.getConfig()
+                .display.isAutoFitWidth
+
+            "quiet_time_enabled" -> generalSettingsManager.getConfig()
+                .notification.isQuietTimeEnabled
 
-            "show_compose_button" -> generalSettingsManager.getSettings().isShowComposeButtonOnMessageList
-            "threaded_view" -> generalSettingsManager.getSettings().isThreadedViewEnabled
-            "messageview_fixedwidth_font" -> generalSettingsManager.getSettings().isUseMessageViewFixedWidthFont
-            "messageview_autofit_width" -> generalSettingsManager.getSettings().isAutoFitWidth
-            "quiet_time_enabled" -> generalSettingsManager.getSettings().isQuietTimeEnabled
             "disable_notifications_during_quiet_time" -> !K9.isNotificationDuringQuietTimeEnabled
-            "privacy_hide_useragent" -> generalSettingsManager.getSettings().privacy.isHideUserAgent
-            "privacy_hide_timezone" -> generalSettingsManager.getSettings().privacy.isHideTimeZone
-            "debug_logging" -> K9.isDebugLoggingEnabled
-            "sync_debug_logging" -> K9.isSyncLoggingEnabled
+            "privacy_hide_useragent" -> generalSettingsManager.getConfig().privacy.isHideUserAgent
+            "privacy_hide_timezone" -> generalSettingsManager.getConfig().privacy.isHideTimeZone
+            "debug_logging" -> generalSettingsManager.getConfig().debugging.isDebugLoggingEnabled
+            "sync_debug_logging" -> generalSettingsManager.getConfig().debugging.isSyncLoggingEnabled
             "sensitive_logging" -> K9.isSensitiveDebugLoggingEnabled
             "volume_navigation" -> K9.isUseVolumeKeysForNavigation
             "enable_telemetry" -> K9.isTelemetryEnabled
@@ -88,8 +111,8 @@ class GeneralSettingsDataStore(
             "disable_notifications_during_quiet_time" -> K9.isNotificationDuringQuietTimeEnabled = !value
             "privacy_hide_useragent" -> setIsHideUserAgent(isHideUserAgent = value)
             "privacy_hide_timezone" -> setIsHideTimeZone(isHideTimeZone = value)
-            "debug_logging" -> K9.isDebugLoggingEnabled = value
-            "sync_debug_logging" -> K9.isSyncLoggingEnabled = value
+            "debug_logging" -> setIsDebugLoggingEnabled(isDebugLoggingEnabled = value)
+            "sync_debug_logging" -> setIsSyncLoggingEnabled(isSyncLoggingEnabled = value)
             "sensitive_logging" -> K9.isSensitiveDebugLoggingEnabled = value
             "volume_navigation" -> K9.isUseVolumeKeysForNavigation = value
             "enable_telemetry" -> setTelemetryEnabled(value)
@@ -120,16 +143,22 @@ class GeneralSettingsDataStore(
     override fun getString(key: String, defValue: String?): String? {
         return when (key) {
             "language" -> appLanguageManager.getAppLanguage()
-            "theme" -> appThemeToString(generalSettingsManager.getSettings().appTheme)
-            "message_compose_theme" -> subThemeToString(generalSettingsManager.getSettings().messageComposeTheme)
-            "messageViewTheme" -> subThemeToString(generalSettingsManager.getSettings().messageViewTheme)
+            "theme" -> appThemeToString(generalSettingsManager.getConfig().display.coreSettings.appTheme)
+            "message_compose_theme" -> subThemeToString(
+                generalSettingsManager.getConfig().display.coreSettings.messageComposeTheme,
+            )
+
+            "messageViewTheme" -> subThemeToString(
+                generalSettingsManager.getConfig().display.coreSettings.messageViewTheme,
+            )
+
             "messagelist_preview_lines" -> K9.messageListPreviewLines.toString()
-            "splitview_mode" -> K9.splitViewMode.name
+            "splitview_mode" -> generalSettingsManager.getConfig().display.coreSettings.splitViewMode.name
             "notification_quick_delete" -> K9.notificationQuickDeleteBehaviour.name
             "lock_screen_notification_visibility" -> K9.lockScreenNotificationVisibility.name
-            "background_ops" -> K9.backgroundOps.name
-            "quiet_time_starts" -> generalSettingsManager.getSettings().quietTimeStarts
-            "quiet_time_ends" -> generalSettingsManager.getSettings().quietTimeEnds
+            "background_ops" -> generalSettingsManager.getConfig().network.backgroundOps.name
+            "quiet_time_starts" -> generalSettingsManager.getConfig().notification.quietTimeStarts
+            "quiet_time_ends" -> generalSettingsManager.getConfig().notification.quietTimeEnds
             "message_list_subject_font" -> K9.fontSizes.messageListSubject.toString()
             "message_list_sender_font" -> K9.fontSizes.messageListSender.toString()
             "message_list_date_font" -> K9.fontSizes.messageListDate.toString()
@@ -153,12 +182,16 @@ class GeneralSettingsDataStore(
         if (value == null) return
 
         when (key) {
-            "language" -> appLanguageManager.setAppLanguage(value)
+            "language" -> {
+                skipSaveSettings = true
+                appLanguageManager.setAppLanguage(value)
+            }
+
             "theme" -> setTheme(value)
             "message_compose_theme" -> setMessageComposeTheme(value)
             "messageViewTheme" -> setMessageViewTheme(value)
             "messagelist_preview_lines" -> K9.messageListPreviewLines = value.toInt()
-            "splitview_mode" -> K9.splitViewMode = K9.SplitViewMode.valueOf(value)
+            "splitview_mode" -> setSplitViewModel(SplitViewMode.valueOf(value.uppercase()))
             "notification_quick_delete" -> {
                 K9.notificationQuickDeleteBehaviour = K9.NotificationQuickDelete.valueOf(value)
             }
@@ -257,142 +290,295 @@ class GeneralSettingsDataStore(
 
     private fun setTheme(value: String) {
         skipSaveSettings = true
-        generalSettingsManager.setAppTheme(stringToAppTheme(value))
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    coreSettings = settings.display.coreSettings.copy(
+                        appTheme = stringToAppTheme(value),
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setMessageComposeTheme(subThemeString: String) {
         skipSaveSettings = true
-        generalSettingsManager.setMessageComposeTheme(stringToSubTheme(subThemeString))
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    coreSettings = settings.display.coreSettings.copy(
+                        messageComposeTheme = stringToSubTheme(
+                            subThemeString,
+                        ),
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setMessageViewTheme(subThemeString: String) {
         skipSaveSettings = true
-        generalSettingsManager.setMessageViewTheme(stringToSubTheme(subThemeString))
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    coreSettings = settings.display.coreSettings.copy(
+                        messageViewTheme = stringToSubTheme(
+                            subThemeString,
+                        ),
+                    ),
+                ),
+            )
+        }
+    }
+
+    private fun setSplitViewModel(mode: SplitViewMode) {
+        skipSaveSettings = true
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    coreSettings = settings.display.coreSettings.copy(
+                        splitViewMode = mode,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setFixedMessageViewTheme(fixedMessageViewTheme: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setFixedMessageViewTheme(fixedMessageViewTheme)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    coreSettings = settings.display.coreSettings.copy(
+                        fixedMessageViewTheme = fixedMessageViewTheme,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsShowStarredCount(isShowStarredCount: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowStarredCount(isShowStarredCount)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isShowStarredCount = isShowStarredCount,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsShowUnifiedInbox(isShowUnifiedInbox: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowUnifiedInbox(isShowUnifiedInbox)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isShowUnifiedInbox = isShowUnifiedInbox,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsShowMessageListStars(isShowMessageListStars: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowMessageListStars(isShowMessageListStars)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isShowMessageListStars = isShowMessageListStars,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsShowAnimations(isShowAnimations: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowAnimations(isShowAnimations)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isShowAnimations = isShowAnimations))
+        }
     }
 
     private fun setIsShowCorrespondentNames(isShowCorrespondentNames: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowCorrespondentNames(isShowCorrespondentNames)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isShowCorrespondentNames = isShowCorrespondentNames))
+        }
     }
 
     private fun setIsMessageListSenderAboveSubject(isMessageListSenderAboveSubject: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsMessageListSenderAboveSubject(isMessageListSenderAboveSubject)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isMessageListSenderAboveSubject = isMessageListSenderAboveSubject,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsShowContactName(isShowContactName: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowContactName(isShowContactName)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isShowContactName = isShowContactName))
+        }
     }
 
     private fun setIsShowContactPicture(isShowContactPicture: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowContactPicture(isShowContactPicture)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isShowContactPicture = isShowContactPicture))
+        }
     }
 
     private fun setIsChangeContactNameColor(isChangeContactNameColor: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsChangeContactNameColor(isChangeContactNameColor)
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isChangeContactNameColor = isChangeContactNameColor))
+        }
     }
 
     private fun setIsColorizeMissingContactPictures(isColorizeMissingContactPictures: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowContactName(isColorizeMissingContactPictures)
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(isColorizeMissingContactPictures = isColorizeMissingContactPictures),
+            )
+        }
     }
 
     private fun setIsUseBackgroundAsUnreadIndicator(isUseBackgroundAsUnreadIndicator: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsUseBackgroundAsUnreadIndicator(
-            isUseBackgroundAsUnreadIndicator = isUseBackgroundAsUnreadIndicator,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(isUseBackgroundAsUnreadIndicator = isUseBackgroundAsUnreadIndicator),
+            )
+        }
     }
 
     private fun setIsShowComposeButtonOnMessageList(isShowComposeButtonOnMessageList: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsShowComposeButtonOnMessageList(
-            isShowComposeButtonOnMessageList = isShowComposeButtonOnMessageList,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isShowComposeButtonOnMessageList = isShowComposeButtonOnMessageList,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsThreadedViewEnabled(isThreadedViewEnabled: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsThreadedViewEnabled(
-            isThreadedViewEnabled = isThreadedViewEnabled,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(
+                    inboxSettings = settings.display.inboxSettings.copy(
+                        isThreadedViewEnabled = isThreadedViewEnabled,
+                    ),
+                ),
+            )
+        }
     }
 
     private fun setIsUseMessageViewFixedWidthFont(isUseMessageViewFixedWidthFont: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsUseMessageViewFixedWidthFont(
-            isUseMessageViewFixedWidthFont = isUseMessageViewFixedWidthFont,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                display = settings.display.copy(isUseMessageViewFixedWidthFont = isUseMessageViewFixedWidthFont),
+            )
+        }
     }
 
     private fun setQuietTimeStarts(quietTimeStarts: String) {
         skipSaveSettings = true
-        generalSettingsManager.setQuietTimeStarts(
-            quietTimeStarts = quietTimeStarts,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                notification = settings.notification.copy(
+                    quietTimeStarts = quietTimeStarts,
+                ),
+            )
+        }
     }
 
     private fun setQuietTimeEnds(quietTimeEnds: String) {
         skipSaveSettings = true
-        generalSettingsManager.setQuietTimeEnds(
-            quietTimeEnds = quietTimeEnds,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                notification = settings.notification.copy(
+                    quietTimeEnds = quietTimeEnds,
+                ),
+            )
+        }
     }
 
     private fun setIsAutoFitWidth(isAutoFitWidth: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsAutoFitWidth(
-            isAutoFitWidth = isAutoFitWidth,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(display = settings.display.copy(isAutoFitWidth = isAutoFitWidth))
+        }
     }
 
     private fun setIsQuietTimeEnabled(isQuietTimeEnabled: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsQuietTimeEnabled(
-            isQuietTimeEnabled = isQuietTimeEnabled,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                notification = settings.notification.copy(
+                    isQuietTimeEnabled = isQuietTimeEnabled,
+                ),
+            )
+        }
     }
 
     private fun setIsHideTimeZone(isHideTimeZone: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsHideTimeZone(
-            isHideTimeZone = isHideTimeZone,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                privacy = settings.privacy.copy(
+                    isHideTimeZone = isHideTimeZone,
+                ),
+            )
+        }
+    }
+
+    private fun setIsDebugLoggingEnabled(isDebugLoggingEnabled: Boolean) {
+        skipSaveSettings = true
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                debugging = settings.debugging.copy(
+                    isDebugLoggingEnabled = isDebugLoggingEnabled,
+                ),
+            )
+        }
+    }
+
+    private fun setIsSyncLoggingEnabled(isSyncLoggingEnabled: Boolean) {
+        skipSaveSettings = true
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                debugging = settings.debugging.copy(
+                    isSyncLoggingEnabled = isSyncLoggingEnabled,
+                ),
+            )
+        }
     }
 
     private fun setIsHideUserAgent(isHideUserAgent: Boolean) {
         skipSaveSettings = true
-        generalSettingsManager.setIsHideUserAgent(
-            isHideUserAgent = isHideUserAgent,
-        )
+        generalSettingsManager.update { settings ->
+            settings.copy(
+                privacy = settings.privacy.copy(
+                    isHideUserAgent = isHideUserAgent,
+                ),
+            )
+        }
     }
 
     private fun appThemeToString(theme: AppTheme) = when (theme) {
@@ -422,9 +608,12 @@ class GeneralSettingsDataStore(
     }
 
     private fun setBackgroundOps(value: String) {
-        val newBackgroundOps = K9.BACKGROUND_OPS.valueOf(value)
-        if (newBackgroundOps != K9.backgroundOps) {
-            K9.backgroundOps = newBackgroundOps
+        val newBackgroundOps = BackgroundOps.valueOf(value)
+        if (newBackgroundOps != generalSettingsManager.getConfig().network.backgroundOps) {
+            skipSaveSettings = true
+            generalSettingsManager.update { settings ->
+                settings.copy(network = settings.network.copy(backgroundOps = newBackgroundOps))
+            }
             jobManager.scheduleAllMailJobs()
         }
     }
