@@ -1,8 +1,12 @@
 package com.fsck.k9.ui.settings.general
 
+import android.content.Context
 import android.net.Uri
 import androidx.lifecycle.ViewModel
 import androidx.lifecycle.viewModelScope
+import app.k9mail.feature.launcher.FeatureLauncherActivity
+import app.k9mail.feature.launcher.FeatureLauncherTarget
+import com.fsck.k9.ui.BuildConfig
 import kotlinx.coroutines.Job
 import kotlinx.coroutines.delay
 import kotlinx.coroutines.flow.Flow
@@ -15,8 +19,7 @@ import net.thunderbird.core.logging.legacy.Log
 class GeneralSettingsViewModel(
     private val logFileWriter: LogFileWriter,
     private val syncDebugFileLogSink: FileLogSink,
-) :
-    ViewModel() {
+) : ViewModel() {
     private var snackbarJob: Job? = null
     private val uiStateFlow = MutableStateFlow<GeneralSettingsUiState>(GeneralSettingsUiState.Idle)
     val uiState: Flow<GeneralSettingsUiState> = uiStateFlow
@@ -34,14 +37,30 @@ class GeneralSettingsViewModel(
         }
     }
 
-    fun fileExport(contentUri: Uri) {
+    fun fileExport(contentUri: String) {
         viewModelScope.launch {
             setExportingState()
             try {
-                syncDebugFileLogSink.export(contentUri.toString())
+                syncDebugFileLogSink.export(contentUri)
                 showSnackbar(GeneralSettingsUiState.Success)
             } catch (e: Exception) {
-                Log.e(e, "Failed to write log to URI: %s", contentUri)
+                Log.e(e, "Failed to write log to URI")
+                showSnackbar(GeneralSettingsUiState.Failure)
+            }
+        }
+    }
+
+    fun showExportSnackbar(isSuccess: Boolean) {
+        viewModelScope.launch {
+            setExportingState()
+            try {
+                if (isSuccess) {
+                    showSnackbar(GeneralSettingsUiState.Success)
+                } else {
+                    showSnackbar(GeneralSettingsUiState.Failure)
+                }
+            } catch (e: Exception) {
+                Log.e(e, "Failed to write log to URI")
                 showSnackbar(GeneralSettingsUiState.Failure)
             }
         }
@@ -70,6 +89,12 @@ class GeneralSettingsViewModel(
         uiStateFlow.value = uiState
     }
 
+    fun onOpenSecretDebugScreen(context: Context) {
+        if (BuildConfig.DEBUG) {
+            FeatureLauncherActivity.launch(context = context, target = FeatureLauncherTarget.SecretDebugSettings)
+        }
+    }
+
     companion object {
         const val DEFAULT_FILENAME = "k9mail-logs.txt"
         const val SNACKBAR_DURATION = 3000L
