@@ -43,9 +43,6 @@ dependencyResolutionManagement {
     }
 }
 
-plugins {
-}
-
 include(
     ":app-k9mail",
     ":app-thunderbird",
@@ -115,6 +112,7 @@ include(
 include(
     ":feature:notification:api",
     ":feature:notification:impl",
+    ":feature:notification:testing",
 )
 
 include(
@@ -127,7 +125,7 @@ include(
 )
 
 include(
-    ":feature:search",
+    ":feature:search:impl-legacy",
 )
 
 include(
@@ -245,6 +243,10 @@ include(
     ":quality:konsist",
 )
 
+include(
+    ":feature:debug-settings",
+)
+
 check(JavaVersion.current().isCompatibleWith(JavaVersion.VERSION_17)) {
     """
         Java 17+ is required to build Thunderbird for Android.
